@@ -9,7 +9,8 @@ my @options = qw(OPTION_ENDPOINT OPTION_HOST OPTION_PORT OPTION_PILICY OPTION_WA
     OPTION_AUTH_PASSWD OPTION_AUTH_TYPE OPTION_CONNECTION);
 my @policies = qw(POLICY_LAST PILICY_ERROR);
 my @api = qw(API_DOCUMENT API_COLLECTION API_CURSOR API_EXAMPLE API_EDGE API_QUERY API_SIMPLE_ALL API_SIMPLE_EXAMPLE
-    API_SIMPLE_FIRST API_SIMPLE_RANGE API_SIMPLE_NEAR API_SIMPLE_WITHIN API_INDEX API_IMPORT API_EDGES API_EXPLAIN);
+    API_SIMPLE_FIRST API_SIMPLE_RANGE API_SIMPLE_NEAR API_SIMPLE_WITHIN API_INDEX API_IMPORT API_EDGES API_EXPLAIN
+    API_KEY API_KEYS);
 
 my @status = qw(NEWBORN UNLOADED LOADED BEING_UNLOADED DELETED CORRUPTED);
 
@@ -48,6 +49,8 @@ use constant {
     API_CURSOR         => '/_api/cursor',
     API_EDGE           => '/_api/edge',
     API_EDGES          => '/_api/edges',
+    API_KEY            => '/_api/key/',
+    API_KEYS           => '/_api/keys/',
     API_EXAMPLE        => '/_api/simple/by-example',
     API_QUERY          => '/_api/query',
     API_EXPLAIN        => '/_api/explain',
